@@ -24,7 +24,7 @@ from ast import literal_eval
 from pathlib import Path
 from _thread import get_ident as _get_ident
 
-from typing import Mapping, Optional, Sequence, Union
+from typing import Mapping, Optional, Sequence, Union, Any, Iterable
 
 # external imports
 import numpy as np
@@ -727,7 +727,7 @@ class AnyPyProcessOutput(collections.OrderedDict):
         return dfout
 
 
-def _recursive_replace(iterable, old, new):
+def _recursive_replace(iterable: Iterable, old: Any, new: Any):
     for i, elem in enumerate(iterable):
         if isinstance(elem, list):
             _recursive_replace(elem, old, new)
@@ -752,7 +752,7 @@ def _parse_data(val):
                 # handle the case where AnyBody has output 'nan' values
                 val2 = val.replace("nan,", ' "nan",')
                 out = literal_eval(val2)
-                recursive_replace(out, "nan", float("nan"))
+                _recursive_replace(out, "nan", float("nan"))
             else:
                 raise SyntaxError
         except (SyntaxError, ValueError):
